package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.ProjectMember;
import org.apache.ibatis.annotations.Param;

/**
 * 项目成员Mapper接口
 *
 * @author ruoyi
 * @date 2025-02-28
 */

public interface ProjectMemberMapper
{
    /**
     * 查询项目成员
     *
     * @param projectId 项目成员主键
     * @return 项目成员
     */
    public ProjectMember selectProjectMemberByProjectId(Long projectId);

    /**
     * 查询项目成员列表
     *
     * @param projectMember 项目成员
     * @return 项目成员集合
     */
    public List<ProjectMember> selectProjectMemberList(ProjectMember projectMember);

    /**
     * 新增项目成员
     *
     * @param projectMember 项目成员
     * @return 结果
     */
    public int insertProjectMember(ProjectMember projectMember);

    /**
     * 修改项目成员
     *
     * @param projectMember 项目成员
     * @return 结果
     */
    public int updateProjectMember(ProjectMember projectMember);

    /**
     * 删除项目成员
     *
     * @param projectId 项目成员主键
     * @return 结果
     */
    public int deleteProjectMemberByProjectId(Long projectId);

    /**
     * 批量删除项目成员
     *
     * @param projectIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteProjectMemberByProjectIds(Long[] projectIds);

    /**
     * 批量新增项目成员
     *
     * @param projectId      项目 ID
     * @param memberIds      成员 ID 列表
     */
    void batchInsertProjectMembers(@Param("projectId") Long projectId, @Param("memberIds") List<Long> memberIds);
    /*
     * 删除项目成员
     * @param projectId 项目 ID
     * @param memberId  成员 ID
     * */
    public void deleteProjectMember(@Param("projectId") Long projectId, @Param("memberId") Long memberId);

    /**
     * 根据用户 ID 查询项目成员列表
     *
     * @param userId 用户 ID
     * @return 项目成员列表
     */
    List<ProjectMember> selectProjectMemberListByUserId(@Param("userId") Long userId);

    /**
     * 根据项目编号和经理ID查询项目成员的用户ID和昵称
     *
     * @param projectNumber 项目编号
     * @param managerId     经理ID
     * @return 项目成员列表
     */
    List<ProjectMember> selectEmployNameListByManagerId(@Param("projectNumber") String projectNumber, @Param("managerId") Long managerId);

}
